@@ -3,6 +3,7 @@
 
 #include "global.h"
 #include <QtXml>
+#include "GVH_SMS_Handler.h"
 
 class GVH_XMLJsonHandler : public QObject, public QXmlDefaultHandler
 {
@@ -31,7 +32,10 @@ protected:
 private:
     QString strChars;
     QString strJson;
+    QString strHtml;
     qint32 nUsableMsgs;
+
+    GVH_SMS_Handler smsHandler;
 };
 
 #endif // GVH_XMLJSONHANDLER_H
