@@ -2,9 +2,10 @@
 #define __GVHISTORY_H__
 
 #include "global.h"
-#include "InboxModel.h"
 #include <QtDeclarative>
 
+class InboxModel;
+
 class GVHistory : public QObject
 {
     Q_OBJECT
